<?php
/**
* Header Functions
*
* @package GridMini WordPress Theme
* @copyright Copyright (C) 2023 ThemesDNA
* @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 or later
* @author ThemesDNA <themesdna@gmail.com>
*/

/**
 * Add a pingback url auto-discovery header for single posts, pages, or attachments.
 */
function gridmini_pingback_header() {
    if ( is_singular() && pings_open() ) {
        echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
    }
}
add_action( 'wp_head', 'gridmini_pingback_header' );

// Get custom-logo URL
function gridmini_custom_logo() {
    if ( ! has_custom_logo() ) {return;}
    $gridmini_custom_logo_id = get_theme_mod( 'custom_logo' );
    $gridmini_logo = wp_get_attachment_image_src( $gridmini_custom_logo_id , 'full' );
    $gridmini_logo_src = $gridmini_logo[0];
    return apply_filters( 'gridmini_custom_logo', $gridmini_logo_src );
}

// Site Title
function gridmini_site_title() {
    if ( is_front_page() && is_home() ) { ?>
            <h1 class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_home() ) { ?>
            <h1 class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_singular() ) { ?>
            <p class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_category() ) { ?>
            <p class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_tag() ) { ?>
            <p class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_author() ) { ?>
            <p class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_archive() && !is_category() && !is_tag() && !is_author() ) { ?>
            <p class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_search() ) { ?>
            <p class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } elseif ( is_404() ) { ?>
            <p class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php } else { ?>
            <h1 class="gridmini-site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
            <?php if ( !(gridmini_get_option('hide_tagline')) ) { ?><p class="gridmini-site-description"><?php bloginfo( 'description' ); ?></p><?php } ?>
    <?php }
}

function gridmini_header_image_destination() {
    $url = home_url( '/' );
    if ( gridmini_get_option('header_image_destination') ) {
        $url = gridmini_get_option('header_image_destination');
    }
    return apply_filters( 'gridmini_header_image_destination', $url );
}

function gridmini_header_image_markup() {
    if ( get_header_image() ) {
        if ( gridmini_get_option('remove_header_image_link') ) {
            the_header_image_tag( array( 'class' => 'gridmini-header-img', 'alt' => '' ) );
        } else { ?>
            <a href="<?php echo esc_url( gridmini_header_image_destination() ); ?>" rel="home" class="gridmini-header-img-link"><?php the_header_image_tag( array( 'class' => 'gridmini-header-img', 'alt' => '' ) ); ?></a>
        <?php }
    }
}

function gridmini_header_image_details() {
    $header_image_custom_title = '';
    if ( gridmini_get_option('header_image_custom_title') ) {
        $header_image_custom_title = gridmini_get_option('header_image_custom_title');
    }

    $header_image_custom_description = '';
    if ( gridmini_get_option('header_image_custom_description') ) {
        $header_image_custom_description = gridmini_get_option('header_image_custom_description');
    }

    if ( !(gridmini_get_option('hide_header_image_details')) ) {
    if ( gridmini_get_option('header_image_custom_text') ) {
        if ( $header_image_custom_title || $header_image_custom_description ) { ?>
            <div class="gridmini-header-image-info">
            <div class="gridmini-header-image-info-inside">
                <?php if ( !(gridmini_get_option('hide_header_image_title')) ) { ?><?php if ( $header_image_custom_title ) { ?><p class="gridmini-header-image-site-title gridmini-header-image-block"><?php echo wp_kses_post( force_balance_tags( do_shortcode($header_image_custom_title) ) ); ?></p><?php } ?><?php } ?>
                <?php if ( !(gridmini_get_option('hide_header_image_description')) ) { ?><?php if ( $header_image_custom_description ) { ?><p class="gridmini-header-image-site-description gridmini-header-image-block"><?php echo wp_kses_post( force_balance_tags( do_shortcode($header_image_custom_description) ) ); ?></p><?php } ?><?php } ?>
            </div>
            </div>
        <?php }
    } else { ?>
        <div class="gridmini-header-image-info">
        <div class="gridmini-header-image-info-inside">
            <?php if ( !(gridmini_get_option('hide_header_image_title')) ) { ?><p class="gridmini-header-image-site-title gridmini-header-image-block"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p><?php } ?>
            <?php if ( !(gridmini_get_option('hide_header_image_description')) ) { ?><p class="gridmini-header-image-site-description gridmini-header-image-block"><?php bloginfo( 'description' ); ?></p><?php } ?>
        </div>
        </div>
    <?php }
    }
}

function gridmini_header_image_wrapper() { ?>
    <div class="gridmini-header-image gridmini-clearfix">
    <?php gridmini_header_image_markup(); ?>
    <?php gridmini_header_image_details(); ?>
    </div>
    <?php
}

function gridmini_header_image() {
    if ( gridmini_get_option('hide_header_image') ) { return; }
    if ( get_header_image() ) {
        gridmini_header_image_wrapper();
    }
}